@@ -1,6 +1,6 @@
 from datetime import datetime, timedelta
 
-import jwt
+from jose import jwt
 
 from frogml_proto.qwak.administration.v0.authentication.authentication_service_pb2 import (
     AuthenticateRequest,
